==> odin_1.8.4.orig.tar.gz: odin-1.8.4/odin/odindialog_new.h <==
/***************************************************************************
                          odindialog_new.h  -  description
                             -------------------
    begin                : Mon Oct 10 21:30:11 CEST 2005
    copyright            : (C) 2003 by Thies H. Jochimsen
    email                : jochimse@cns.mpg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ODINDIALOG_NEW_H
#define ODINDIALOG_NEW_H

#include <qobject.h>

#include <odinqt/jdxwidget.h>



class NewMethDialog : public QObject, public GuiDialog {
 Q_OBJECT

 public:
  NewMethDialog(QWidget *parent, JcampDxBlock& files);
  ~NewMethDialog();

 public:
  void updateWidget();

 signals:
  void valueChanged();


 private slots:
  void done();
  void cancel();
  void emit_valueChanged();

 private:

  GuiGridLayout* grid;
  GuiButton*   pb_done;
  GuiButton*   pb_cancel;
  JDXwidget* fileswidget;
};



#endif

==> odin_1.8.8.orig.tar.gz: odin-1.8.8/odin/odindialog_new.h <==
/***************************************************************************
                          odindialog_new.h  -  description
                             -------------------
    begin                : Mon Oct 10 21:30:11 CEST 2005
    copyright            : (C) 2000-2014 by Thies H. Jochimsen
    email                : thies@jochimsen.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ODINDIALOG_NEW_H
#define ODINDIALOG_NEW_H

#include <qobject.h>

#include <odinqt/jdxwidget.h>



class NewMethDialog : public QObject, public GuiDialog {
 Q_OBJECT

 public:
  NewMethDialog(QWidget *parent, JcampDxBlock& files);
  ~NewMethDialog();

 public:
  void updateWidget();

 signals:
  void valueChanged();


 private slots:
  void done();
  void cancel();
  void emit_valueChanged();

 private:

  GuiGridLayout* grid;
  GuiButton*   pb_done;
  GuiButton*   pb_cancel;
  JDXwidget* fileswidget;
};



#endif
